diff --git a/.gitattributes b/.gitattributes
index b26e810e18faab325de018299b65343478df9dae..85c3f24d079e6fdcf9e9a2fa3ec4c566db8e245e 100644
--- a/.gitattributes
+++ b/.gitattributes
@@ -2640,16 +2640,16 @@ RTCP/Storage/include/Storage/FastFileStream.h -text
 RTCP/Storage/include/Storage/Format.h -text
 RTCP/Storage/include/Storage/HDF5Attributes.h -text
 RTCP/Storage/include/Storage/IOPriority.h -text
-RTCP/Storage/include/Storage/MSWriterDAL.h -text
 RTCP/Storage/include/Storage/MSWriterFile.h -text
+RTCP/Storage/include/Storage/MSWriterLDA.h -text
 RTCP/Storage/include/Storage/MSWriterNull.h -text
 RTCP/Storage/include/Storage/MeasurementSetFormat.h -text
 RTCP/Storage/include/Storage/OutputThread.h -text
 RTCP/Storage/include/Storage/TBB_Writer.h -text
 RTCP/Storage/src/FastFileStream.cc -text
 RTCP/Storage/src/Format.cc -text
-RTCP/Storage/src/MSWriterDAL.cc -text
 RTCP/Storage/src/MSWriterFile.cc -text
+RTCP/Storage/src/MSWriterLDA.cc -text
 RTCP/Storage/src/MSWriterNull.cc -text
 RTCP/Storage/src/MeasurementSetFormat.cc -text
 RTCP/Storage/src/OutputThread.cc -text
@@ -2657,8 +2657,8 @@ RTCP/Storage/src/TBB_Writer.cc -text
 RTCP/Storage/src/TBB_Writer_main.cc -text
 RTCP/Storage/src/gnuplotMS.sh -text
 RTCP/Storage/src/plotMS.cc -text
-RTCP/Storage/test/tDAL.cc -text
 RTCP/Storage/test/tFastFileStream.cc -text
+RTCP/Storage/test/tLDA.cc -text
 RTCP/Storage/test/tMeasurementSetFormat.parset-j2000 -text
 RTCP/Storage/test/tMeasurementSetFormat.parset-sun -text
 SAS/Beaminfo/CMakeLists.txt -text
diff --git a/RTCP/Storage/CMakeLists.txt b/RTCP/Storage/CMakeLists.txt
index 4388dc440aa8dc1d885a7c98d909afc252d6014e..e21bbd5e5b1e395d5d0f8d77d050a4866f7bb54e 100644
--- a/RTCP/Storage/CMakeLists.txt
+++ b/RTCP/Storage/CMakeLists.txt
@@ -4,7 +4,7 @@ lofar_package(Storage 1.0 DEPENDS Common ApplCommon Interface MSLofar LofarStMan
 
 include(LofarFindPackage)
 lofar_find_package(Casacore COMPONENTS casa measures ms tables REQUIRED)
-lofar_find_package(DAL REQUIRED)
+lofar_find_package(LDA REQUIRED)
 lofar_find_package(HDF5 REQUIRED)
 
 add_subdirectory(include/Storage)
diff --git a/RTCP/Storage/src/CMakeLists.txt b/RTCP/Storage/src/CMakeLists.txt
index f1d1c58d6dbf97fd9f2075d306c758e5478bc541..b135cd4b0b3613384f209380358db0a89aa026f3 100644
--- a/RTCP/Storage/src/CMakeLists.txt
+++ b/RTCP/Storage/src/CMakeLists.txt
@@ -9,13 +9,13 @@ lofar_add_library(storage
   OutputThread.cc
   SubbandWriter.cc
   MSWriter.cc
-  MSWriterDAL.cc
+  MSWriterLDA.cc
   MSWriterNull.cc
   MSWriterFile.cc
   Format.cc
-  MeasurementSetFormat.cc
-  TBB_Writer_main.cc
-  TBB_Writer.cc)
+  MeasurementSetFormat.cc)
+#  TBB_Writer_main.cc
+#  TBB_Writer.cc)
 
 install(PROGRAMS
   gnuplotMS.sh
@@ -28,4 +28,4 @@ install(FILES
 lofar_add_bin_program(Storage_main Storage_main.cc)
 lofar_add_bin_program(plotMS plotMS.cc)
 lofar_add_bin_program(versionstorage versionstorage.cc)
-lofar_add_bin_program(TBB_Writer_main TBB_Writer_main.cc)
+#lofar_add_bin_program(TBB_Writer_main TBB_Writer_main.cc)
diff --git a/RTCP/Storage/src/OutputThread.cc b/RTCP/Storage/src/OutputThread.cc
index ddefbccbef7b538caf694b71c0b276fb9dd916d3..73de63beca20af5aa52e8ce4e2fdc078232a31bc 100644
--- a/RTCP/Storage/src/OutputThread.cc
+++ b/RTCP/Storage/src/OutputThread.cc
@@ -25,7 +25,7 @@
 
 #include <Common/StringUtil.h>
 #include <Storage/MSWriterFile.h>
-#include <Storage/MSWriterDAL.h>
+#include <Storage/MSWriterLDA.h>
 #include <Storage/MSWriterNull.h>
 #include <Storage/MeasurementSetFormat.h>
 #include <Storage/OutputThread.h>
@@ -159,7 +159,7 @@ void OutputThread::createMS()
     // HDF5 writer requested
     switch (itsOutputType) {
       case BEAM_FORMED_DATA:
-        itsWriter = new MSWriterDAL<float,3>(path.c_str(), itsParset, itsStreamNr, itsIsBigEndian);
+        itsWriter = new MSWriterLDA<float,3>(path.c_str(), itsParset, itsStreamNr, itsIsBigEndian);
         break;
       default:
         itsWriter = new MSWriterFile(path, itsOutputType == BEAM_FORMED_DATA);
diff --git a/RTCP/Storage/test/CMakeLists.txt b/RTCP/Storage/test/CMakeLists.txt
index 77d72bbd126f811b3c1643dc48ea347c01e998cf..00a59edf1caae1b404afb370b7baf89598de06fc 100644
--- a/RTCP/Storage/test/CMakeLists.txt
+++ b/RTCP/Storage/test/CMakeLists.txt
@@ -3,6 +3,6 @@
 include(LofarCTest)
 
 lofar_add_test(tMeasurementSetFormat tMeasurementSetFormat.cc)
-lofar_add_test(tDAL tDAL.cc)
+lofar_add_test(tLDA tLDA.cc)
 lofar_add_test(tFastFileStream tFastFileStream.cc)
 #lofar_add_test(tAH_TestStorage tAH_TestStorage.cc)
diff --git a/RTCP/Storage/include/Storage/MSWriterDAL.h b/RTCP/Storage/include/Storage/MSWriterLDA.h
similarity index 81%
rename from RTCP/Storage/include/Storage/MSWriterDAL.h
rename to RTCP/Storage/include/Storage/MSWriterLDA.h
index 6b32a1ecd6b44817d48c653e3a531d7768b89cd9..9f2985c7431c0887274a2da31ee244d96398e466 100644
--- a/RTCP/Storage/include/Storage/MSWriterDAL.h
+++ b/RTCP/Storage/include/Storage/MSWriterLDA.h
@@ -1,6 +1,6 @@
 //  MSMriterDAL.h: implementation of MSWriter using the DAL to write HDF5
 //
-//  Copyright (C) 2001
+//  Copyright (C) 2011
 //  ASTRON (Netherlands Foundation for Research in Astronomy)
 //  P.O.Box 2, 7990 AA Dwingeloo, The Netherlands, seg@astron.nl
 //
@@ -18,13 +18,13 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
-//  $Id: MSWriterImpl.h 11891 2008-10-14 13:43:51Z gels $
+//  $Id: MSWriterLDA.h 11891 2011-10-14 13:43:51Z gels $
 //
 //////////////////////////////////////////////////////////////////////
 
 
-#ifndef LOFAR_STORAGE_MSWRITERDAL_H
-#define LOFAR_STORAGE_MSWRITERDAL_H
+#ifndef LOFAR_STORAGE_MSWRITERLDA_H
+#define LOFAR_STORAGE_MSWRITERLDA_H
 
 //# Includes
 #include <Common/LofarTypes.h>
@@ -42,11 +42,11 @@ namespace LOFAR
 
   namespace RTCP
   {
-    template<typename T, unsigned DIM> class MSWriterDAL : public MSWriterFile
+    template<typename T, unsigned DIM> class MSWriterLDA : public MSWriterFile
     {
     public:
-      MSWriterDAL(const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian);
-      ~MSWriterDAL();
+      MSWriterLDA(const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian);
+      ~MSWriterLDA();
       virtual void write(StreamableData *data);
     private:
       const Transpose2 &itsTransposeLogic;
@@ -1,6 +1,6 @@
-//  MSMriterDAL.h: implementation of MSWriter using the DAL to write HDF5
+//  MSMriterLDA.h: implementation of MSWriter using the LDA to write HDF5
 //
diff --git a/RTCP/Storage/src/MSWriterDAL.cc b/RTCP/Storage/src/MSWriterLDA.cc
similarity index 96%
rename from RTCP/Storage/src/MSWriterDAL.cc
rename to RTCP/Storage/src/MSWriterLDA.cc
index 9a1cb2c04a48b8b604ed326d0491c300f9056847..5ca09d6c687feae1b3f43b7952fe08a41ad25a1b 100644
--- a/RTCP/Storage/src/MSWriterDAL.cc
+++ b/RTCP/Storage/src/MSWriterLDA.cc
@@ -1,4 +1,4 @@
 //# MSWriterDAL: an implementation of MSWriter using the DAL to write HDF5
 //#
 //#  Copyright (C) 2011
 //#  ASTRON (Netherlands Foundation for Research in Astronomy)
@@ -26,11 +26,11 @@
 #include <Common/SystemUtil.h>
 
 #include <Storage/MSWriter.h>
-#include <Storage/MSWriterDAL.h>
+#include <Storage/MSWriterLDA.h>
 
 #include <lofar/BF_File.h>
 
-using namespace DAL;
+using namespace LDA;
 using namespace std;
 
 #include <Common/Thread/Mutex.h>
@@ -101,7 +101,7 @@ namespace LOFAR
     // uses global locks too anyway.
     static Mutex HDF5Mutex;
 
-    template <typename T,unsigned DIM> MSWriterDAL<T,DIM>::MSWriterDAL (const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian)
+    template <typename T,unsigned DIM> MSWriterLDA<T,DIM>::MSWriterLDA (const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian)
     :
       MSWriterFile(forceextension(string(filename),".raw"),false),
       itsTransposeLogic(parset.transposeLogic()),
@@ -157,11 +157,11 @@ namespace LOFAR
           break;
 
         case INVALID_STOKES:
-          LOG_ERROR("MSWriterDAL asked to write INVALID_STOKES");
+          LOG_ERROR("MSWriterLDA asked to write INVALID_STOKES");
           return;
       }    
 
-      LOG_DEBUG_STR("MSWriterDAL: opening " << filename);
+      LOG_DEBUG_STR("MSWriterLDA: opening " << filename);
 
       // create the top structure
       BF_File file(h5filename, BF_File::CREATE);
@@ -408,11 +408,11 @@ namespace LOFAR
       stokesDS.nofSamples()     .set(dims[0]);
     }
 
-    template <typename T,unsigned DIM> MSWriterDAL<T,DIM>::~MSWriterDAL()
+    template <typename T,unsigned DIM> MSWriterLDA<T,DIM>::~MSWriterLDA()
     {
     }
 
-    template <typename T,unsigned DIM> void MSWriterDAL<T,DIM>::write(StreamableData *data)
+    template <typename T,unsigned DIM> void MSWriterLDA<T,DIM>::write(StreamableData *data)
     {
       SampleData<T,DIM> *sdata = dynamic_cast<SampleData<T,DIM> *>(data);
 
@@ -434,7 +434,7 @@ namespace LOFAR
     }
 
     // specialisation for FinalBeamFormedData
-    template class MSWriterDAL<float,3>;
+    template class MSWriterLDA<float,3>;
 
   } // namespace RTCP
 } // namespace LOFAR
@@ -1,4 +1,4 @@
-//# MSWriterDAL: an implementation of MSWriter using the DAL to write HDF5
+//# MSWriterLDA: an implementation of MSWriter using the LDA to write HDF5
 //#
 //#  Copyright (C) 2011
diff --git a/RTCP/Storage/test/tDAL.cc b/RTCP/Storage/test/tLDA.cc
similarity index 90%
rename from RTCP/Storage/test/tDAL.cc
rename to RTCP/Storage/test/tLDA.cc
index a687b6dd96c057778ed40e6e0a2acf7cf0db98be..980b88db800ab025d8d5da206f33a417c4a83069 100644
--- a/RTCP/Storage/test/tDAL.cc
+++ b/RTCP/Storage/test/tLDA.cc
@@ -1,4 +1,4 @@
 //# tDAL: Test HDF5 routines through DAL
 //#
 //#  Copyright (C) 2011
 //#  ASTRON (Netherlands Foundation for Research in Astronomy)
@@ -22,18 +22,18 @@
 
 #include <lofar_config.h>
 
-#ifdef HAVE_DAL
+#ifdef HAVE_LDA
 
 #include <dal_version.h>
 #include <iostream>
 #include <string>
 
 using namespace std;
-using namespace DAL;
+using namespace LDA;
 
 int main() {
   if (!check_hdf5_versions()) {
-    cerr << "HDF5 version mismatch. DAL was compiled with " << get_dal_hdf5_version() << ", our headers are " << get_current_hdf5_header_version() << ", our library is " << get_current_hdf5_lib_version() << endl;
+    cerr << "HDF5 version mismatch. LDA was compiled with " << get_dal_hdf5_version() << ", our headers are " << get_current_hdf5_header_version() << ", our library is " << get_current_hdf5_lib_version() << endl;
     return 1;
   }
@@ -1,4 +1,4 @@
-//# tDAL: Test HDF5 routines through DAL
+//# tLDA: Test HDF5 routines through LDA
 //#
 //#  Copyright (C) 2011